@@ -23,7 +23,21 @@ import socket
 import subprocess
 import threading
 import time
+
 from OVirtAgentLogic import AgentLogicBase, DataRetriverBase
+from hooks import Hooks
+
+
+# avoid pep8 warnings
+def import_json():
+    try:
+        import json
+        return json
+    except ImportError:
+        import simplejson
+        return simplejson
+json = import_json()
+
 
 CredServer = None
 try:
@@ -39,6 +53,7 @@ except ImportError:
 
 
 _GUEST_SCRIPTS_INSTALL_PATH = '/usr/share/ovirt-guest-agent'
+_GUEST_HOOKS_CONFIG_PATH = '/etc/ovirt-guest-agent/hooks.d'
 
 
 def _get_script_path(name):
@@ -273,6 +288,20 @@ class LinuxDataRetriver(DataRetriverBase):
     def getOsVersion(self):
         return os.uname()[2]
 
+    def getContainerList(self):
+        cmd = [_get_script_path('ovirt-container-list')]
+        # skip if not available
+        if not os.path.exists(cmd[0]):
+            return []
+        logging.debug('Executing ovirt-container-list command')
+        result = []
+        try:
+            p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+            result = json.loads(p.stdout.read())
+        except Exception:
+            logging.exception('ovirt-container-list invocation failed')
+        return result
+
     def getOsInfo(self):
         cmd = [_get_script_path('ovirt-osinfo')]
         logging.debug('Executing ovirt-osinfo command: %s', cmd)
@@ -442,6 +471,8 @@ class LinuxVdsAgent(AgentLogicBase):
                                                  "ignore_zero_size_fs")
         self.commandHandler = CommandHandlerLinux(self)
         self.cred_server = CredServer()
+        self.hooks = Hooks(logging.getLogger('Hooks'),
+                           _GUEST_HOOKS_CONFIG_PATH)
 
     def run(self):
         self.cred_server.start()
